widget/functions/functions library

Functions

doesFileExist(String? filePath) Future<bool>
downloadAndSetInCache(String mediaUrl, {required GetStorage getStorage}) Future<void>
downloadMediaToCache(String mediaUrl) Future<String?>
downloadMediaToLocalCache(String mediaUrl, String mediaName) Future<String?>
Download locally the file and return the file path if succes, or null if error.
loadMedia(String mediaUrl, {required GetStorage getStorage}) Future<CachedMediaInfo?>
Return CachedMediaInfo? after either finding in cache or downloading then set in cache